@@ -2,7 +2,7 @@
 """
 @Author: ChenXiaolei
 @Date: 2020-05-11 21:46:17
-@LastEditTime: 2020-05-12 19:49:45
+@LastEditTime: 2020-05-25 16:29:57
 @LastEditors: ChenXiaolei
 @Description: 
 """
@@ -13,7 +13,7 @@ from urllib import parse
 class CodingHelper():
     @classmethod
     def url_encode(self, text, coding='utf-8'):
-        return parse.urlencode(text, encoding='utf-8')
+        return parse.quote_plus(text, encoding='utf-8')
 
     @classmethod
     def url_decode(self, text, coding='utf-8'):
