@@ -2,13 +2,13 @@
 """
 @Author: ChenXiaolei
 @Date: 2020-03-06 23:17:54
-@LastEditTime: 2020-04-27 16:49:15
+@LastEditTime: 2020-05-13 20:01:53
 @LastEditors: ChenXiaolei
 @Description: Handler基础类
 """
 
 # seven_framework import
-from .base import *
+from .base_handler import *
 
 # third package import
 from pycket.session import SessionManager
@@ -28,9 +28,9 @@ class BaseCookieHandler(BaseHandler):
         super(BaseCookieHandler, self).__init__(*argc, **argkw)
         self.session = SessionManager(self)
 
-    def prepare(self):
+    def prepare_ext(self):
         """
-        @description: 置于任何请求方法前被调用
+        @description: 置于任何请求方法前被调用扩展
         @last_editors: ChenXiaolei
         """
         pass
