@@ -2,7 +2,7 @@
 """
 @Author: ChenXiaolei
 @Date: 2020-03-06 23:17:54
-@LastEditTime: 2020-05-14 11:27:24
+@LastEditTime: 2020-05-24 16:32:39
 @LastEditors: ChenXiaolei
 @Description: Handler基础类
 """
@@ -16,6 +16,7 @@ import json
 import io
 import bleach
 import asyncio
+import traceback
 
 # tornado import
 from tornado.concurrent import run_on_executor
@@ -72,27 +73,34 @@ class BaseHandler(tornado.web.RequestHandler):
         @description: 置于任何请求方法前被调用(请勿重写此函数,可重写prepare_ext)
         @last_editors: ChenXiaolei
         """
-        http_request = dict(
-            request_time=TimeHelper.get_now_format_time(),
-            expend_time=self.request.request_time(),
-            response_time=TimeHelper.get_now_format_time(),
-            request_ip=self.get_remote_ip(),
-            method=self.request.method,
-            url=self.request.uri,
-            request_params=self.request.arguments,
-            response_code=self.get_status(),
-        )
-        
-        http_request_json = json.dumps(http_request,cls=JsonEncoder)
-        
-        http_log = config.get_value("http_log")
-        if http_log and http_log==True:
-            self.logger_info.info(http_request_json)
-        else:
-            print('\033[33m' + http_request_json + '\033[0m')
+        try:
+            if "Content-Type" in self.request.headers and self.request.headers["Content-type"].lower().find("application/json") >= 0 and self.request.body:
+                request_params = json.loads(self.request.body)
+            else:
+                request_params = self.request.arguments
+            http_request = dict(
+                request_time=TimeHelper.get_now_format_time(),
+                expend_time=self.request.request_time(),
+                response_time=TimeHelper.get_now_format_time(),
+                request_ip=self.get_remote_ip(),
+                method=self.request.method,
+                url=self.request.uri,
+                request_params=request_params,
+                http_status_code=self.get_status(),
+            )
+
+            http_request_json = json.dumps(http_request, cls=JsonEncoder)
+
+            http_log = config.get_value("http_log")
+            if http_log and http_log == True:
+                self.logger_info.info(http_request_json)
+            else:
+                print('\033[33m' + http_request_json + '\033[0m')
+
+            self.prepare_ext()
+        except Exception as ex:
+            self.logger_error.exception('error_info:')
 
-        self.prepare_ext()
-    
     def prepare_ext(self):
         """
         @description: 置于任何请求方法前被调用扩展
@@ -126,7 +134,8 @@ class BaseHandler(tornado.web.RequestHandler):
                 if field_str in self.request.arguments:
                     field_val = self.get_argument(field_str)
                     if field_val is not None:
-                        setattr(model_entity, field_str, self.html_clean(field_val))
+                        setattr(model_entity, field_str,
+                                self.html_clean(field_val))
             except Exception as exp:
                 return False
         return True
@@ -139,7 +148,8 @@ class BaseHandler(tornado.web.RequestHandler):
         """
         dict_body = {}
         if self.request.body:
-            dict_str = str.split(CodingHelper.url_decode(self.request.body.decode("unicode_escape'")), "&")
+            dict_str = str.split(CodingHelper.url_decode(
+                self.request.body.decode("unicode_escape'")), "&")
             for item in dict_str:
                 kv = str.split(item, "=")
                 dict_body[kv[0]] = kv[1]
@@ -309,45 +319,38 @@ class BaseHandler(tornado.web.RequestHandler):
         self.redirect(url, permanent, status)
 
 
-def filter_check_params(must_params=None, optional_params=None):
+def filter_check_params(must_params=None):
     """
     @description: 参数过滤装饰器 仅限handler使用,
                   提供参数的检查及获取参数功能
                   装饰器使用方法:
-                  @filter_check_params("param_a","param_b","param_c","param_d")  或
-                  @filter_check_params(["param_a","param_b"],["param_c","param_d"])
+                  @filter_check_params("param_a,param_b,param_c")  或
+                  @filter_check_params(["param_a","param_b,param_c"])
                   参数获取方法:
                   self.request_params[param_key]
     @param must_params: 必须传递的参数集合
-    @param optional_params: 可选传递的参数集合
     @last_editors: ChenXiaolei
     """
     def check_params(handler):
         def wrapper(self, **args):
-            if not must_params and not optional_params:
-                self.reponse_json_error_params()
-                return
             self.request_params = {}
             if type(must_params) == str:
                 must_array = must_params.split(",")
-            if optional_params and type(optional_params) == str:
-                optional_array = optional_params.split(",")
-
-            if must_params and len(must_array) > 0:
-                for param in must_array:
-                    value = self.get_param(param)
-                    if not value or value == "":
+            if type(must_params) == list:
+                must_array = must_params
+            if "Content-Type" in self.request.headers and self.request.headers["Content-type"].lower().find("application/json") >= 0:
+                json_params = json.loads(self.request.body)
+                if json_params:
+                    for field in json_params:
+                        self.request_params[field] = json_params[field]
+            else:
+                for field in self.request.arguments:
+                    self.request_params[field] = self.get_param(field)
+            if must_params:
+                for must_param in must_array:
+                    if not must_param in self.request_params or self.request_params[must_param] == "":
                         self.reponse_json_error_params()
                         return
-                    self.request_params[param] = value
-
-            if optional_params and len(optional_array) > 0:
-                for param in optional_array:
-                    value = self.get_param(param)
-                    if value and value != "":
-                        self.request_params[param] = value
             return handler(self, **args)
-
         return wrapper
-
     return check_params
